@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999, 2000, 2001, 2002, 2003 Lorenzo Bettini <http://www.lorenzobettini.it>
+** Copyright (C) 1999-2007 Lorenzo Bettini <http://www.lorenzobettini.it>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ class DocGenerator
   string doc_header;
   string doc_footer;
   string css_url;
+  string doc_background;
   bool entire_doc;
 
   DocTemplate docTemplate;
@@ -45,10 +46,11 @@ class DocGenerator
  public:
   DocGenerator(const string &s, const string &i,
                const string &h, const string &f, const string &c,
+               const string &back,
                bool entire,
                const string &start_tmpl, const string &end_tmpl) : title (s),
     gen_source_highlight_version (true), input_file_name (i), doc_header (h),
-    doc_footer (f), css_url (c), entire_doc (entire),
+    doc_footer (f), css_url (c), doc_background(back), entire_doc (entire),
     docTemplate(DocTemplate(start_tmpl, end_tmpl)) {}
   DocGenerator() {}
   ~DocGenerator() {}
