@@ -27,12 +27,20 @@ public:
 
     ~RegExpEngineDebug();
 
+    void setInteractive(bool i) { interactive = i; }
 protected:
+  /// whether it's an interactive debug session
+  bool interactive;
+
     virtual void enterState(int index);
     virtual void exitAll();
     virtual void exitState(int level);
     virtual void format(int index, const std::string& s);
 
+    /**
+     * Waits for a step command (if in interactive mode)
+     */
+    virtual void step();
 };
 
 #endif
